@@ -2,7 +2,8 @@ mod utils;
 
 #[cfg(test)]
 mod trade {
-    use crypto_msg_parser::{extract_symbol, parse_trade, MarketType, TradeSide};
+    use crypto_market_type::MarketType;
+    use crypto_msg_parser::{extract_symbol, parse_trade, TradeSide};
 
     #[test]
     fn spot() {
@@ -144,7 +145,8 @@ mod trade {
 
 #[cfg(test)]
 mod funding_rate {
-    use crypto_msg_parser::{parse_funding_rate, MarketType};
+    use crypto_market_type::MarketType;
+    use crypto_msg_parser::parse_funding_rate;
 
     #[test]
     fn inverse_swap() {
@@ -183,7 +185,8 @@ mod funding_rate {
 
 #[cfg(test)]
 mod l2_orderbook {
-    use crypto_msg_parser::{extract_symbol, parse_l2, MarketType};
+    use crypto_market_type::MarketType;
+    use crypto_msg_parser::{extract_symbol, parse_l2};
     use float_cmp::approx_eq;
 
     #[test]
